==> jc-1.4.0.tar.gz: java/security/PrivilegedActionException.h <==
// public class java.security.PrivilegedActionException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8c58386db95b8b94 java_security_PrivilegedActionException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_security_PrivilegedActionException_H_
#define _JC_java_security_PrivilegedActionException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_security_PrivilegedActionException$sub_refs	_jc_java_security_PrivilegedActionException$sub_refs;
typedef struct _jc_java_security_PrivilegedActionException$sub_nonrefs	_jc_java_security_PrivilegedActionException$sub_nonrefs;
typedef struct _jc_java_security_PrivilegedActionException$refs	_jc_java_security_PrivilegedActionException$refs;
typedef struct _jc_java_security_PrivilegedActionException$nonrefs	_jc_java_security_PrivilegedActionException$nonrefs;
typedef struct _jc_java_security_PrivilegedActionException$object	_jc_java_security_PrivilegedActionException$object;

typedef struct _jc_java_security_PrivilegedActionException$fields_struct	_jc_java_security_PrivilegedActionException$fields_struct;
typedef const struct _jc_java_security_PrivilegedActionException$vmethods	_jc_java_security_PrivilegedActionException$vmethods;
typedef const struct _jc_java_security_PrivilegedActionException$vtable	_jc_java_security_PrivilegedActionException$vtable;
typedef const struct _jc_java_security_PrivilegedActionException$vtype	_jc_java_security_PrivilegedActionException$vtype;

// Class fields structure
struct _jc_java_security_PrivilegedActionException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_PrivilegedActionException$fields_struct _jc_java_security_PrivilegedActionException$class_fields;

// Constructors
extern void _jc_java_security_PrivilegedActionException$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_security_PrivilegedActionException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *);
extern struct _jc_java_lang_Exception$object *_jc_java_security_PrivilegedActionException$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_PrivilegedActionException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_PrivilegedActionException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_security_PrivilegedActionException$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_java_security_PrivilegedActionException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_PrivilegedActionException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *);
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *);
};

// Vtable
struct _jc_java_security_PrivilegedActionException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_PrivilegedActionException$vmethods	java_security_PrivilegedActionException;
};

// Vtype
struct _jc_java_security_PrivilegedActionException$vtype {
	_jc_type			type;
	_jc_java_security_PrivilegedActionException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_PrivilegedActionException$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_java_security_PrivilegedActionException$refs {
    _jc_java_security_PrivilegedActionException$sub_refs	java_security_PrivilegedActionException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_PrivilegedActionException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_PrivilegedActionException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_PrivilegedActionException$sub_nonrefs	java_security_PrivilegedActionException;
};

// Object instance structure
struct _jc_java_security_PrivilegedActionException$object {
	_jc_java_security_PrivilegedActionException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_PrivilegedActionException$vtype	*vtype;
	_jc_java_security_PrivilegedActionException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_PrivilegedActionException$vtype _jc_java_security_PrivilegedActionException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_PrivilegedActionException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_PrivilegedActionException$class_object;

#endif	/* _JC_java_security_PrivilegedActionException_H_ */

==> jc-1.4.6.tar.gz: java/security/PrivilegedActionException.h <==
// public class java.security.PrivilegedActionException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8c58386db95b8b94 java_security_PrivilegedActionException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_security_PrivilegedActionException_H_
#define _JC_java_security_PrivilegedActionException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_security_PrivilegedActionException$sub_refs	_jc_java_security_PrivilegedActionException$sub_refs;
typedef struct _jc_java_security_PrivilegedActionException$sub_nonrefs	_jc_java_security_PrivilegedActionException$sub_nonrefs;
typedef struct _jc_java_security_PrivilegedActionException$refs	_jc_java_security_PrivilegedActionException$refs;
typedef struct _jc_java_security_PrivilegedActionException$nonrefs	_jc_java_security_PrivilegedActionException$nonrefs;
typedef struct _jc_java_security_PrivilegedActionException$object	_jc_java_security_PrivilegedActionException$object;

typedef struct _jc_java_security_PrivilegedActionException$fields_struct	_jc_java_security_PrivilegedActionException$fields_struct;
typedef const struct _jc_java_security_PrivilegedActionException$vmethods	_jc_java_security_PrivilegedActionException$vmethods;
typedef const struct _jc_java_security_PrivilegedActionException$vtable	_jc_java_security_PrivilegedActionException$vtable;
typedef const struct _jc_java_security_PrivilegedActionException$vtype	_jc_java_security_PrivilegedActionException$vtype;

// Class fields structure
struct _jc_java_security_PrivilegedActionException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_PrivilegedActionException$fields_struct _jc_java_security_PrivilegedActionException$class_fields;

// Constructors
extern void _jc_java_security_PrivilegedActionException$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_security_PrivilegedActionException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Exception$object *_jc_java_security_PrivilegedActionException$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_PrivilegedActionException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_PrivilegedActionException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_security_PrivilegedActionException$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_java_security_PrivilegedActionException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_PrivilegedActionException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_PrivilegedActionException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_PrivilegedActionException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_PrivilegedActionException$vmethods	java_security_PrivilegedActionException;
};

// Vtype
struct _jc_java_security_PrivilegedActionException$vtype {
	_jc_type			type;
	_jc_java_security_PrivilegedActionException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_PrivilegedActionException$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_java_security_PrivilegedActionException$refs {
    _jc_java_security_PrivilegedActionException$sub_refs	java_security_PrivilegedActionException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_PrivilegedActionException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_PrivilegedActionException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_PrivilegedActionException$sub_nonrefs	java_security_PrivilegedActionException;
};

// Object instance structure
struct _jc_java_security_PrivilegedActionException$object {
	_jc_java_security_PrivilegedActionException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_PrivilegedActionException$vtype	*vtype;
	_jc_java_security_PrivilegedActionException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_PrivilegedActionException$vtype _jc_java_security_PrivilegedActionException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_PrivilegedActionException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_PrivilegedActionException$class_object;

#endif	/* _JC_java_security_PrivilegedActionException_H_ */
